#!/usr/bin/python3
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.pdns_sqlite import ZoneRepo, RecordRepo, Record

import sqlite3

def record_json(record):
    return {
        "id": record.id,
        "name": record.name,
        "type": record.type,
        "content": record.content,
        "ttl": record.ttl,
    }

def zone_json(zone):
    return {
        "id": zone.id,
        "name": zone.name,
        "type": zone.type,
        "soa": record_json(zone.soa),
        "serial": zone.soa.serial,
        "metadata": {str(k): [str(v) for v in l] for k, l in zone.metadata.items()},
    }

def run_module():
    module_args = dict(
        path=dict(type='str', required=True),
        type=dict(type='str', default='zone', choices=['zone', 'record']),
        name=dict(type='str', default=''),
        # if type=record and zone!='' list only records for that zone
        zone=dict(type='str', default=''),
    )

    module = AnsibleModule(
        argument_spec=module_args,
        supports_check_mode=True
    )

    result = {
        "changed": False,
        "zones": [],
        "records": [],
    }
    zones, records = ([], [])
    
    con = sqlite3.connect(module.params["path"])
    rrepo = RecordRepo(con)
    zrepo = ZoneRepo(con)
    
    if module.params["type"] == 'zone':
        if module.params["name"]:
            zones = [zrepo.get_by_name(module.params["name"])]
        else:
            zones = zrepo.list()
    if module.params["type"] == 'record':
        kwargs = {}
        if module.params["zone"] and module.params["name"]:
            kwargs['name'] = Record.make_name(module.params["zone"], module.params["name"])
        elif module.params["zone"]:
            zone = zrepo.get_by_name(module.params["zone"])
            kwargs['zone_id'] = zone.id if zone is not None else -1
        elif module.params["name"]:
            kwargs['name'] = module.params["name"]
        records = rrepo.list(**kwargs)

    result["zones"] = [zone_json(z) for z in zones]
    result["records"] = [record_json(r) for r in records]

    con.close()
    module.exit_json(**result)

if __name__ == '__main__':
    run_module()