#!/usr/bin/python3
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.pdns_sqlite import Record, RecordRepo, ZoneRepo

import sqlite3

def run_module():
    module_args = dict(
        path=dict(type='str', required=True),
        zone=dict(type='str', required=True),
        name=dict(type='str', required=True),
        type=dict(type='str', required=True),
        content=dict(type='str', required=True),
        ttl=dict(type='int', default=900),
        state=dict(type='str', default='present', choices=['absent', 'present']),
        # if set to True and state=present replace all records having (zone, name, type) with this record
        unique=dict(type='bool', default=False),
    )

    module = AnsibleModule(
        argument_spec=module_args,
        supports_check_mode=False
    )

    result = {
        "changed": False,
    }
    
    con = sqlite3.connect(module.params["path"])
    zrepo = ZoneRepo(con)
    repo = RecordRepo(con)
    
    zone = zrepo.get_by_name(module.params["zone"])
    if zone is None:
        module.fail_json("Zone '{}' does not exist".format(module.params["zone"]))

    rr = Record(
        None, 
        zone.id, 
        Record.make_name(zone.name, module.params["name"]),
        module.params["type"], 
        module.params["content"], 
        module.params["ttl"]
    )

    if module.params["state"] == 'present' and module.params["unique"]:
        records = repo.find(rr, ignore_content=True)

        found = [r for r in records if r.content == rr.content]
        if found:
            found = found[0]
            found.ttl = rr.ttl
            repo.save(found)
        else:
            repo.create(rr)
        
        for record in records:
            if record.id != found.id:
                repo.delete(record)

    elif module.params["state"] == 'present' and not module.params["unique"]:
        records = repo.find(rr, ignore_content=False)
        
        if not records:
            repo.create(rr)
        else:
            for record in records:
                record.ttl = rr.ttl
                repo.save(record)
    
    elif module.params["state"] == 'absent':
        records = repo.find(rr, ignore_content=False)
        for record in records:
            repo.delete(record)
    
    if repo.changed:
        zone.increment_serial()
        zrepo.save(zone)

    con.commit()
    result['changed'] = result['changed'] or repo.changed
    con.close()
    module.exit_json(**result)

if __name__ == '__main__':
    run_module()