#!/usr/bin/python3
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.pdns_sqlite import Zone, ZoneRepo

import sqlite3

def run_module():
    module_args = dict(
        path=dict(type='str', required=True),
        name=dict(type='str', required=True),
        algorithm=dict(type='str', default=''),
        secret=dict(type='str', default=''),
        state=dict(type='str', default='present', choices=['absent', 'present']),
    )

    module = AnsibleModule(
        argument_spec=module_args,
        supports_check_mode=False
    )

    result = {
        "changed": False,
    }
    
    con = sqlite3.connect(module.params["path"])
    affected_rows = -1

    if module.params["state"] == 'present':
        if not module.params["algorithm"] or not module.params["secret"]:
            module.fail_json("Missing algorithm or secret params with state=present")
        data = [module.params["name"], module.params["algorithm"], module.params["secret"]]

        q = "select id from tsigkeys where name = ? and algorithm = ? and secret = ?"
        if con.execute(q, data).fetchone() is not None:
            affected_rows = 0
        else:
            q = "insert or replace into tsigkeys (name, algorithm, secret) values (?, ?, ?)"
            affected_rows = con.execute(q, data).rowcount

    if module.params["state"] == 'absent':
        fields = (
            ('name', module.params["name"]), 
            ('algorithm', module.params["algorithm"]), 
            ('secret', module.params["secret"]), 
        )
        fields = [f for f in fields if f[1]]
        if not fields:
            module.fail_json("No identifying fields for delete")
        
        q = "delete from tsigkeys where "
        q += " and ".join([f[0] + " = ?" for f in fields])
        data = [f[1] for f in fields]
        affected_rows = con.execute(q, data).rowcount

    con.commit()
    result['changed'] = affected_rows > 0
    con.close()
    module.exit_json(**result)

if __name__ == '__main__':
    run_module()