#!/usr/bin/python3
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.pdns_sqlite import Zone, ZoneRepo

import sqlite3

def run_module():
    module_args = dict(
        path=dict(type='str', required=True),
        name=dict(type='str', required=True),
        repl_type=dict(type='str', default='NATIVE', choices=['NATIVE']),
        state=dict(type='str', default='present', choices=['absent', 'present']),
    )

    module = AnsibleModule(
        argument_spec=module_args,
        supports_check_mode=False
    )

    result = {
        "changed": False,
    }
    
    con = sqlite3.connect(module.params["path"])
    repo = ZoneRepo(con)
    zone = repo.get_by_name(module.params["name"])

    if module.params["state"] == 'present':
        if zone is None:
            zone = Zone(None, module.params["name"], module.params["repl_type"])
            repo.create(zone)
        else:
            zone.type = module.params["repl_type"]
            repo.save(zone)
    elif module.params["state"] == 'absent':
        if zone is not None:
            repo.delete(zone)

    con.commit()
    result['changed'] = result['changed'] or repo.changed
    con.close()
    module.exit_json(**result)

if __name__ == '__main__':
    run_module()