#!/usr/bin/python3
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.pdns_sqlite import Zone, ZoneRepo

import sqlite3

def run_module():
    module_args = dict(
        path=dict(type='str', required=True),
        zone=dict(type='str', required=True),
        attribute=dict(type='str', required=True),
        values=dict(type='list', elements='str', default=None),
        state=dict(type='str', default='present', choices=['absent', 'present', 'replaced']),
    )

    module = AnsibleModule(
        argument_spec=module_args,
        supports_check_mode=False
    )

    result = {
        "changed": False,
    }
    
    con = sqlite3.connect(module.params["path"])
    repo = ZoneRepo(con)

    zone = repo.get_by_name(module.params["zone"])
    if zone is None:
        module.fail_json("Zone '{}' does not exist".format(module.params["zone"]))
    
    user_values = module.params["values"] if module.params["values"] is not None else []
    old_values = zone.metadata.get(module.params["attribute"], [])
    new_values = old_values
    
    if module.params["state"] == 'present':
        new_values = set(old_values) | set(user_values)
    elif module.params["state"] == 'absent':
        new_values = set(old_values) - set(user_values)
    elif module.params["state"] == 'replaced':
        new_values = user_values

    zone.metadata[module.params["attribute"]] = new_values
    repo.save(zone)

    con.commit()
    result['changed'] = result['changed'] or repo.changed or repo.metadata.changed
    result['values'] = list(new_values)
    con.close()
    module.exit_json(**result)

if __name__ == '__main__':
    run_module()